class Colors:
    BACKGROUND = (30, 30, 35)      # Dunkles Grau
    PRIMARY = (60, 140, 255)       # Modernes Blau
    TEXT = (240, 240, 240)         # Fast Weiß
    HOVER = (80, 160, 255)         # Helleres Blau für Hover
    BUTTON_TEXT = (255, 255, 255)

class Style:
    FONT = "Arial" # Später Roboto oder Inter laden
    ROUNDING = 10  # Runde Ecken Radius